pub fn lookup_key_info_by_name(name: &str) -> Option<&'static AttrKeyInfo>Expand description
Look up a key info by name using the global registry.
Returns None if no key with this name is registered.
Uses a lazy-initialized hash map for O(1) lookup after first access.